**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name              TablesAndChairs
Sequence         1 - Introduction to mathematical programming using GAMS
Type             LP
GAMS language      Introduction to the GAMS language
Description
"A company sells chairs and small tables which it produces using a stock of 16 wood units, 10 fabric units, and employs a worker for 40 hours of labour.

1 chair requires : 1 hour of labour, 1 wood unit, 1 fabric unit

1 table requires : 4 hours of labour, 1 wood unit.

A chair costs 15, a table costs 30.
Determine the production of chairs and tables which makes it possible to maximize the company turnover. "

$Offtext
*-----------------------------------------------------------------------------*


*----------                          DECLARATION                     ----------*
SET
F furniture /chairs, tab/
;


*----------                          DATA                       ----------*
SCALARS
A_WOOD     availability of wood units              /16/
A_FAB      availability of fabric units            /10/
A_LAB     availability of hours of labour          /40/
;

PARAMETERS
W(F)     wood needs per piece of furniture (units)         /TAB 1,   CHAIRS 1/
Fb(F)    fabric needs per piece of furniture (units)       /CHAIRS 1/
L(F)     labour needs per piece of furniture (hours)       /TAB 4,   CHAIRS 1/
PRICE(F)  price per piece of furniture (euros)             /TAB 30,  CHAIRS 15/
;


*----------                         MODEL                          ----------*
VARIABLES
Z        total turnover of the company
;

POSITIVE VARIABLES
NU(F)    number of units for every piece of furniture
;

EQUATIONS
WOOD
FABRIC
LABOUR
OBJECTIVE
;

WOOD..       sum(F, NU(F)*W(F)) =l= A_WOOD ;
FABRIC..     sum(F, NU(F) * Fb(F)) =l= A_FAB ;
LABOUR..     sum(F, NU(F)*L(F)) =l= A_LAB ;
OBJECTIVE..  sum(F, PRICE(F)*NU(F)) =e= Z ;

MODEL TablesAndChairs /all/ ;


*----------                        SOLUTION                         ----------*
SOLVE TablesAndChairs using LP maximizing Z ;


